==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoFaultFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IoFaultFluent<A extends IoFaultFluent<A>> extends BaseFluent<A>{
  public IoFaultFluent() {
  }
  public IoFaultFluent(IoFault instance) {
    instance = (instance != null ? instance : new IoFault());

    if (instance != null) {
      this.withErrno(instance.getErrno());
      this.withWeight(instance.getWeight());
      this.withErrno(instance.getErrno());
      this.withWeight(instance.getWeight());
    }
  }
  private Integer errno;
  private Integer weight;
  public Integer getErrno() {
    return this.errno;
  }
  public A withErrno(Integer errno) {
    this.errno=errno; return (A) this;
  }
  public boolean hasErrno() {
    return this.errno != null;
  }
  public Integer getWeight() {
    return this.weight;
  }
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  public boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IoFaultFluent that = (IoFaultFluent) o;
    if (!java.util.Objects.equals(errno, that.errno)) return false;

    if (!java.util.Objects.equals(weight, that.weight)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(errno,  weight,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (errno != null) { sb.append("errno:"); sb.append(errno + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoFaultFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IoFaultFluent<A extends IoFaultFluent<A>> extends BaseFluent<A>{
  public IoFaultFluent() {
  }
  
  public IoFaultFluent(IoFault instance) {
    this.copyInstance(instance);
  }
  private Integer errno;
  private Integer weight;
  
  protected void copyInstance(IoFault instance) {
    instance = (instance != null ? instance : new IoFault());
  
    if (instance != null) {
        this.withErrno(instance.getErrno());
        this.withWeight(instance.getWeight());
        this.withErrno(instance.getErrno());
        this.withWeight(instance.getWeight());
      }
  }
  
  public Integer getErrno() {
    return this.errno;
  }
  
  public A withErrno(Integer errno) {
    this.errno=errno; return (A) this;
  }
  
  public boolean hasErrno() {
    return this.errno != null;
  }
  
  public Integer getWeight() {
    return this.weight;
  }
  
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  
  public boolean hasWeight() {
    return this.weight != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IoFaultFluent that = (IoFaultFluent) o;
    if (!java.util.Objects.equals(errno, that.errno)) return false;
  
    if (!java.util.Objects.equals(weight, that.weight)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(errno,  weight,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (errno != null) { sb.append("errno:"); sb.append(errno + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  

}
